@@ -26,9 +26,14 @@ class feature_selection():
 
 
         FeaList=self.data.columns.tolist()
-        FeaList.remove(self.target)
+        if self.target in FeaList:
+            FeaList.remove(self.target)
+            x = self.data.drop(self.target, axis=1)
+        else:
+            x = self.data
+
         NFeaFrame=pd.DataFrame(columns=['ElimFeature','score'])
-        x = self.data.drop(self.target, axis=1)
+
         for i in range(1,self.data.shape[1]):
             RF=ensemble.RandomForestRegressor(n_estimators=n_estimators)
             y=self.data[self.target]
