@@ -451,6 +451,8 @@ def pdp_plot(pdp_isolate_out, feature_name, center=True, plot_pts_dist=False, pl
                           count_ax=None, **pdp_plot_params)
 
     axes = {'title_ax': title_ax, 'pdp_ax': pdp_ax}
+
+    plt.show()
     return fig, axes
 
 
@@ -485,6 +487,7 @@ class PDPInteract:
         self.feature_types = feature_types
         self.feature_grids = feature_grids
         self.pdp_isolate_outs = pdp_isolate_outs
+        self.count_data = pdp
         self.pdp = pdp
 
 
@@ -584,6 +587,7 @@ def pdp_interact(model, dataset, model_features, features, num_grid_points=None,
     ice_lines = pd.concat(grid_results, axis=0).reset_index(drop=True)
     pdp = ice_lines.groupby(feature_list, as_index=False).mean()
 
+
     # combine the final results
     pdp_interact_params = {'n_classes': n_classes, 'features': features, 'feature_types': feature_types,
                            'feature_grids': feature_grids}
@@ -600,6 +604,8 @@ def pdp_interact(model, dataset, model_features, features, num_grid_points=None,
         pdp_interact_out = PDPInteract(
             which_class=None, pdp_isolate_outs=pdp_isolate_outs, pdp=pdp, **pdp_interact_params)
 
+    # pdp_interact_out.count_data=pdp_interact_out.pdp
+
     return pdp_interact_out
 
 
@@ -799,5 +805,7 @@ def pdp_interact_plot(pdp_interact_out, feature_names, plot_type='contour', x_qu
 
     axes = {'title_ax': title_ax, 'pdp_inter_ax': inter_ax}
 
+    plt.show()
+
     return fig, axes
 
