@@ -1,7 +1,8 @@
 import eli5
 import matplotlib.pyplot as plt
 import pandas as pd
-
+import warnings
+warnings.filterwarnings("ignore")
 
 
 def pi_trans(model,feature_names,preserve):
@@ -33,5 +34,6 @@ def pi_trans(model,feature_names,preserve):
 def pi_plot(pi_pd):
     plt.figure()
     plt.barh(pi_pd['feature'],pi_pd['weight'])
+    plt.title("Permutation importance")
     plt.show()
 
